Package: MSstatsPTM
Type: Package
Title: Statistical Characterization of Post-translational Modifications
Version: 2.13.0
Date: 2024-11-25
Description: MSstatsPTM provides general statistical methods for quantitative 
    characterization of post-translational modifications (PTMs). Supports DDA, 
    DIA, SRM, and tandem mass tag (TMT) labeling. Typically, the 
    analysis involves the quantification of PTM sites (i.e., modified residues) 
    and their corresponding proteins, as well as the integration of the 
    quantification results. MSstatsPTM provides functions for summarization, 
    estimation of PTM site abundance, and detection of changes in PTMs across 
    experimental conditions. 
Authors@R: c(
    person("Devon", "Kohler", email = "kohler.d@northeastern.edu", role = c("aut")),
    person("Tsung-Heng", "Tsai", email="tsai.tsungheng@gmail.com", role=c("aut")),
    person("Anthony", "Wu", email = "wu.anthon@northeastern.edu", role = c("aut", "cre")),
    person("Deril", "Raju", email = "raju.d@northeastern.edu", role = "aut"),
    person("Ting", "Huang", email = "thuang0703@gmail.com", role=c("aut")),
    person("Mateusz", "Staniak", email = "mtst@mstaniak.pl", role = c("aut")),
  	person("Meena", "Choi", email = "mnchoi67@gmail.com", role="aut"),
  	person("Olga", "Vitek", email = "o.vitek@northeastern.edu", role = "aut"))
License: Artistic-2.0
Depends: R (>= 4.3)
Imports: dplyr, gridExtra, stringr, stats, ggplot2, stringi, grDevices,
        MSstatsTMT, MSstatsConvert, MSstats, data.table, Rcpp,
        Biostrings, checkmate, ggrepel, plotly, htmltools
Suggests: knitr, rmarkdown, tinytest, covr, mockery, testthat (>=
        3.0.0)
LazyData: true
LinkingTo: Rcpp
VignetteBuilder: knitr
biocViews: ImmunoOncology, MassSpectrometry, Proteomics, Software,
        DifferentialExpression, OneChannel, TwoChannel, Normalization,
        QualityControl
BugReports: https://github.com/Vitek-Lab/MSstatsPTM/issues
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/MSstatsPTM
git_branch: devel
git_last_commit: c7e1180
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: yes
Packaged: 2025-10-31 23:04:14 UTC; biocbuild
Author: Devon Kohler [aut],
  Tsung-Heng Tsai [aut],
  Anthony Wu [aut, cre],
  Deril Raju [aut],
  Ting Huang [aut],
  Mateusz Staniak [aut],
  Meena Choi [aut],
  Olga Vitek [aut]
Maintainer: Anthony Wu <wu.anthon@northeastern.edu>
