# Generated by roxygen2: do not edit by hand

export(DIANNtoMSstatsPTMFormat)
export(FragPipetoMSstatsPTMFormat)
export(MSstatsPTMSiteLocator)
export(MaxQtoMSstatsPTMFormat)
export(MetamorpheusToMSstatsPTMFormat)
export(PDtoMSstatsPTMFormat)
export(PStoMSstatsPTMFormat)
export(ProgenesistoMSstatsPTMFormat)
export(ProteinProspectortoMSstatsPTMFormat)
export(SkylinetoMSstatsPTMFormat)
export(SpectronauttoMSstatsPTMFormat)
export(annotSite)
export(dataProcessPTM)
export(dataProcessPlotsPTM)
export(dataSummarizationPTM)
export(dataSummarizationPTM_TMT)
export(designSampleSizePTM)
export(groupComparisonPTM)
export(groupComparisonPlotsPTM)
export(locateMod)
export(locatePTM)
export(tidyFasta)
import(ggplot2)
importFrom(Biostrings,readAAStringSet)
importFrom(MSstats,MSstatsContrastMatrix)
importFrom(MSstats,dataProcess)
importFrom(MSstats,designSampleSize)
importFrom(MSstats,groupComparison)
importFrom(MSstats,theme_msstats)
importFrom(MSstatsConvert,DIANNtoMSstatsFormat)
importFrom(MSstatsConvert,FragPipetoMSstatsFormat)
importFrom(MSstatsConvert,MSstatsBalancedDesign)
importFrom(MSstatsConvert,MSstatsLogsSettings)
importFrom(MSstatsConvert,MSstatsSaveSessionInfo)
importFrom(MSstatsConvert,MaxQtoMSstatsFormat)
importFrom(MSstatsConvert,MetamorpheusToMSstatsFormat)
importFrom(MSstatsConvert,PDtoMSstatsFormat)
importFrom(MSstatsConvert,ProgenesistoMSstatsFormat)
importFrom(MSstatsConvert,ProteinProspectortoMSstatsTMTFormat)
importFrom(MSstatsConvert,SkylinetoMSstatsFormat)
importFrom(MSstatsConvert,SpectronauttoMSstatsFormat)
importFrom(MSstatsTMT,MaxQtoMSstatsTMTFormat)
importFrom(MSstatsTMT,PDtoMSstatsTMTFormat)
importFrom(MSstatsTMT,PhilosophertoMSstatsTMTFormat)
importFrom(MSstatsTMT,groupComparisonTMT)
importFrom(MSstatsTMT,proteinSummarization)
importFrom(Rcpp,sourceCpp)
importFrom(checkmate,assertCharacter)
importFrom(checkmate,assertChoice)
importFrom(checkmate,assertLogical)
importFrom(checkmate,assertNumeric)
importFrom(data.table,`%like%`)
importFrom(data.table,`:=`)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,is.data.table)
importFrom(data.table,melt)
importFrom(data.table,rbindlist)
importFrom(data.table,setDT)
importFrom(data.table,setcolorder)
importFrom(data.table,setnames)
importFrom(data.table,tstrsplit)
importFrom(dplyr,bind_rows)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,ungroup)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,dev.off)
importFrom(grDevices,hcl)
importFrom(grDevices,pdf)
importFrom(gridExtra,grid.arrange)
importFrom(plotly,add_trace)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(plotly,style)
importFrom(plotly,subplot)
importFrom(rlang,.data)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,qnorm)
importFrom(stats,xtabs)
importFrom(stringi,stri_sub_replace_all)
importFrom(stringr,fixed)
importFrom(stringr,regex)
importFrom(stringr,str_extract)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_match)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_split_i)
importFrom(stringr,str_trim)
useDynLib(MSstatsPTM, .registration=TRUE)
