# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

extract_protein_name <- function(ptm_list, protein_list) {
    .Call(`_MSstatsPTM_extract_protein_name`, ptm_list, protein_list)
}

